# Workspace Settings Overview
### On this page
  * [Basic Settings](https://help.sap.com/docs/leanix/ea/workspace-settings-overview#basic-settings)
  * [Advanced Settings](https://help.sap.com/docs/leanix/ea/workspace-settings-overview#advanced-settings)
  * [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/workspace-settings-overview#discovery-and-integrations)


Overview of settings available in the workspace administration area.
Settings in the administration area are grouped into the following categories:
  * Basic Settings
  * Advanced Settings
  * Discovery and Integrations
